@@ -46,21 +46,9 @@ except ImportError: # pragma: no cover
     # Python 3
     from urllib.parse import urlencode
 
-from .vendor.requests import request, Session
-from .vendor.requests.packages import urllib3
-from .vendor.requests.exceptions import RequestException
-
-# Disable pyopenssl. It breaks SSL connection pool when SSL connection is
-# closed unexpectedly by the server. And we don't need SNI anyway.
-try:
-    from .vendor.requests.packages.urllib3.contrib import pyopenssl
-    pyopenssl.extract_from_urllib3()
-except ImportError:
-    pass
-
-# Disable SNI related Warning. The API does not rely on it
-urllib3.disable_warnings(urllib3.exceptions.SNIMissingWarning)
-urllib3.disable_warnings(urllib3.exceptions.SecurityWarning)
+from requests import request, Session
+from requests.packages import urllib3
+from requests.exceptions import RequestException
 
 from .config import config
 from .consumer_key import ConsumerKeyRequest
@@ -367,6 +355,8 @@ class Client(object):
             the default
         """
         kwargs = self._canonicalize_kwargs(kwargs)
+        if not kwargs:
+            kwargs = None
         return self.call('PUT', _target, kwargs, _need_auth)
 
     def post(self, _target, _need_auth=True, **kwargs):
@@ -382,6 +372,8 @@ class Client(object):
             the default
         """
         kwargs = self._canonicalize_kwargs(kwargs)
+        if not kwargs:
+            kwargs = None
         return self.call('POST', _target, kwargs, _need_auth)
 
     def delete(self, _target, _need_auth=True, **kwargs):
@@ -479,11 +471,11 @@ class Client(object):
         else:
             raise APIError(json_result.get('message'), response=result)
 
-    def raw_call(self, method, path, data=None, need_auth=True):
+    def raw_call(self, method, path, data=None, need_auth=True, headers=None):
         """
         Lowest level call helper. If ``consumer_key`` is not ``None``, inject
         authentication headers and sign the request.
-        Will return a vendored ``requests.Response`` object or let any
+        Will return ``requests.Response`` object or let any
         ``requests`` exception pass through.
 
         Request signature is a sha1 hash on following fields, joined by '+'
@@ -498,12 +490,17 @@ class Client(object):
         :param str path: api entrypoint to call, relative to endpoint base path
         :param data: any json serializable data to send as request's body
         :param boolean need_auth: if False, bypass signature
+        :param dict headers: A dict containing the headers that should be sent to
+                             the OVH API. ``raw_call`` will override the
+                             OVH API authentication headers, as well as
+                             the Content-Type header.
         """
         body = ''
         target = self._endpoint + path
-        headers = {
-            'X-Ovh-Application': self._application_key
-        }
+
+        if headers is None:
+            headers = {}
+        headers['X-Ovh-Application'] = self._application_key
 
         # include payload
         if data is not None:
