@@ -31,7 +31,7 @@ import mock
 import json
 from collections import OrderedDict
 
-from ovh.vendor import requests
+import requests
 
 from ovh.client import Client, ENDPOINTS
 from ovh.exceptions import (
@@ -245,6 +245,12 @@ class testClient(unittest.TestCase):
         self.assertEqual(m_call.return_value, api.post(FAKE_URL, **PAYLOAD))
         m_call.assert_called_once_with('POST', FAKE_URL, PAYLOAD, True)
 
+    @mock.patch.object(Client, 'call')
+    def test_post_no_body(self, m_call):
+        api = Client(ENDPOINT, APPLICATION_KEY, APPLICATION_SECRET, CONSUMER_KEY)
+        self.assertEqual(m_call.return_value, api.post(FAKE_URL))
+        m_call.assert_called_once_with('POST', FAKE_URL, None, True)
+
     @mock.patch.object(Client, 'call')
     def test_put(self, m_call):
         PAYLOAD = {
@@ -258,6 +264,12 @@ class testClient(unittest.TestCase):
         self.assertEqual(m_call.return_value, api.put(FAKE_URL, **PAYLOAD))
         m_call.assert_called_once_with('PUT', FAKE_URL, PAYLOAD, True)
 
+    @mock.patch.object(Client, 'call')
+    def test_put_no_body(self, m_call):
+        api = Client(ENDPOINT, APPLICATION_KEY, APPLICATION_SECRET, CONSUMER_KEY)
+        self.assertEqual(m_call.return_value, api.put(FAKE_URL))
+        m_call.assert_called_once_with('PUT', FAKE_URL, None, True)
+
     ## test core function
 
     @mock.patch('ovh.client.Session.request')
@@ -421,6 +433,23 @@ class testClient(unittest.TestCase):
         r = api.raw_call(FAKE_METHOD, FAKE_PATH, None, False)
         self.assertEqual(r, "Let's assume requests will return this")
 
+    @mock.patch('ovh.client.Session.request', return_value="Let's assume requests will return this")
+    def test_raw_call_with_headers(self, m_req):
+        api = Client(ENDPOINT, APPLICATION_KEY, APPLICATION_SECRET)
+        r = api.raw_call(FAKE_METHOD, FAKE_PATH, None, False, headers={
+            'Custom-Header': "1",
+        })
+        self.assertEqual(r, "Let's assume requests will return this")
+        m_req.assert_called_once_with(
+            FAKE_METHOD, BASE_URL+FAKE_PATH,
+            headers={
+                'Custom-Header': "1",
+                'X-Ovh-Application': APPLICATION_KEY,
+            },
+            data='',
+            timeout=TIMEOUT
+        )
+
     # Perform real API tests.
     def test_endpoints(self):
         for endpoint in ENDPOINTS.keys():
